==> qtop_2.2.5.orig.tar.gz: Top-2.2.5/base-qt/BaseIconNames.h <==
#ifndef BaseIconNames_h
#define BaseIconNames_h

// $Id: BaseIconNames.h,v 1.2 2014/02/25 10:28:39 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include <QString>

//! namespace for base icons static name wrapper
namespace IconNames
{

    static const QString AboutQt = "qt-logo.png";
    static const QString Add = "list-add.png";
    static const QString Color = "format-fill-color.png";
    static const QString SelectColor = "color-picker.png";
    static const QString Configure = "configure.png";
    static const QString Copy = "edit-copy.png";
    static const QString Cut = "edit-cut.png";
    static const QString Delete = "user-trash.png";
    static const QString DialogCancel = "dialog-cancel.png";
    static const QString DialogClose = "dialog-close.png";
    static const QString DialogOk = "dialog-ok.png";
    static const QString DialogAccept = "dialog-ok-apply.png";
    static const QString Edit = "document-edit.png";
    static const QString EditClear = "edit-clear-locationbar-rtl.png";
    static const QString Exit = "application-exit.png";
    static const QString Find = "edit-find.png";
    static const QString SelectFont = "preferences-desktop-font.png";
    static const QString Help = "help-contents.png";
    static const QString Lock = "document-encrypt.png";
    static const QString Open = "document-open.png";
    static const QString OpenFolder = "document-open-folder.png";
    static const QString Paste = "edit-paste.png";
    static const QString Print = "document-print.png";
    static const QString PrintPreview = "document-print-preview.png";
    static const QString Redo = "edit-redo.png";
    static const QString Reload = "view-refresh.png";
    static const QString Remove = "list-remove.png";
    static const QString Rename = "edit-rename.png";
    static const QString Revert = "document-revert.png";
    static const QString Run = "system-run.png";
    static const QString ShowMenu = "show-menu.png";
    static const QString Undo = "edit-undo.png";

    static const QString Information = "dialog-information.png";
    static const QString Warning = "dialog-warning.png";

    static const QString Previous = "arrow-left.png";
    static const QString Next = "arrow-right.png";
    static const QString Html = "text-html.png";
    static const QString SymbolicLink = "emblem-symbolic-link.png";

    // configuration icons
    static const QString PreferencesGeneral = "system-run.png";
    static const QString PreferencesNavigation = "input-mouse.png";
    static const QString PreferencesColors = "preferences-desktop-color.png";
    static const QString PreferencesLists = "view-list-tree.png";
    static const QString PreferencesMultipleViews = "view-split-left-right.png";
    static const QString PreferencesRecentFiles = "document-open-recent.png";
    static const QString PreferencesFileAssociations = "preferences-desktop-filetype-association.png";
    static const QString PreferencesAnimations = "tool-animator.png";
    static const QString PreferencesEdition = "edit-rename.png";
    static const QString PreferencesAppearance = "preferences-desktop-theme.png";
    static const QString PreferencesTransparency = "preferences-desktop-theme.png";
    static const QString PreferencesUnsorted = "preferences-other.png";
    static const QString PreferencesPrinting = "document-print.png";
    static const QString PreferencesNotifications = "preferences-desktop-notification.png";
    static const QString PreferencesMainWindow = "preferences-system-windows-actions.png";
    static const QString PreferencesBackground = "preferences-desktop-wallpaper.png";
    static const QString PreferencesBookMarks = "bookmarks.png";
    static const QString PreferencesServer = "network-server.png";
    static const QString PreferencesCache = "preferences-web-browser-cache.png";

};

#endif

==> qtop_2.3.1.orig.tar.gz: Top-2.3.1/base-qt/BaseIconNames.h <==
#ifndef BaseIconNames_h
#define BaseIconNames_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include <QString>

//* namespace for base icons static name wrapper
namespace IconNames
{

    static const QString AboutQt = "qt-logo.png";
    static const QString Add = "list-add.png";
    static const QString Color = "format-fill-color.png";
    static const QString SelectColor = "color-picker.png";
    static const QString Configure = "configure.png";
    static const QString Copy = "edit-copy.png";
    static const QString Cut = "edit-cut.png";
    static const QString Delete = "user-trash.png";
    static const QString DialogCancel = "dialog-cancel.png";
    static const QString DialogClose = "dialog-close.png";
    static const QString DialogOk = "dialog-ok.png";
    static const QString DialogAccept = "dialog-ok-apply.png";
    static const QString Edit = "document-edit.png";
    static const QString EditClear = "edit-clear-locationbar-rtl.png";
    static const QString Exit = "application-exit.png";
    static const QString Find = "edit-find.png";
    static const QString FindPrevious = "arrow-up-double.png";
    static const QString FindNext = "arrow-down-double.png";
    static const QString SelectFont = "preferences-desktop-font.png";
    static const QString Help = "help-contents.png";
    static const QString Lock = "document-encrypt.png";
    static const QString Open = "document-open.png";
    static const QString OpenFolder = "document-open-folder.png";
    static const QString Paste = "edit-paste.png";
    static const QString Print = "document-print.png";
    static const QString PrintPreview = "document-print-preview.png";
    static const QString Redo = "edit-redo.png";
    static const QString Reload = "view-refresh.png";
    static const QString Remove = "list-remove.png";
    static const QString Rename = "edit-rename.png";
    static const QString Revert = "document-revert.png";
    static const QString Run = "system-run.png";
    static const QString ShowMenu = "show-menu.png";
    static const QString Undo = "edit-undo.png";

    static const QString Information = "help-about.png";
    static const QString DialogInformation = "dialog-information.png";
    static const QString DialogWarning = "dialog-warning.png";

    static const QString Previous = "arrow-left.png";
    static const QString Next = "arrow-right.png";
    static const QString Html = "text-html.png";
    static const QString SymbolicLink = "emblem-symbolic-link.png";

    // configuration icons
    static const QString PreferencesGeneral = "system-run.png";
    static const QString PreferencesNavigation = "input-mouse.png";
    static const QString PreferencesColors = "preferences-desktop-color.png";
    static const QString PreferencesLists = "view-list-tree.png";
    static const QString PreferencesMultipleViews = "view-split-left-right.png";
    static const QString PreferencesRecentFiles = "document-open-recent.png";
    static const QString PreferencesFileAssociations = "preferences-desktop-filetype-association.png";
    static const QString PreferencesEdition = "edit-rename.png";
    static const QString PreferencesAppearance = "preferences-desktop-theme.png";
    static const QString PreferencesTransparency = "preferences-desktop-theme.png";
    static const QString PreferencesUnsorted = "preferences-other.png";
    static const QString PreferencesPrinting = "document-print.png";
    static const QString PreferencesNotifications = "preferences-desktop-notification.png";
    static const QString PreferencesMainWindow = "preferences-system-windows-actions.png";
    static const QString PreferencesBackground = "preferences-desktop-wallpaper.png";
    static const QString PreferencesBookMarks = "bookmarks.png";
    static const QString PreferencesServer = "network-server.png";
    static const QString PreferencesCache = "preferences-web-browser-cache.png";

};

#endif
